/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.shibboleth.common.config.attribute.filtering.match.uapprove;

import javax.xml.namespace.QName;

import jp.gakunin.shibboleth.common.attribute.filtering.provider.match.uapprove.AttributeInMetadataMatchFunctor;

import org.opensaml.xml.util.XMLHelper;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.w3c.dom.Element;

import edu.internet2.middleware.shibboleth.common.config.attribute.filtering.BaseFilterBeanDefinitionParser;

/**
 * Bean definition parser for {@link AttributeInMetadataMatchFunctor}s.
 */
public class AttributeInMetadataMatchFunctorBeanDefinitionParser extends BaseFilterBeanDefinitionParser {

    /** Schema type. */
    public static final QName SCHEMA_TYPE = new QName(UapproveMatchFunctorNamespaceHandler.NAMESPACE,
            "AttributeInMetadata");

    /** {@inheritDoc} */
    protected void doParse(final Element configElement, final BeanDefinitionBuilder builder) {
        super.doParse(configElement, builder);

        boolean flag = true;
        if (configElement.hasAttributeNS(null, "onlyIfRequired")) {
            flag = XMLHelper.getAttributeValueAsBoolean(configElement.getAttributeNodeNS(null, "onlyIfRequired"));
        }
        builder.addPropertyValue("onlyIfRequired", flag);

        flag = false;
        if (configElement.hasAttributeNS(null, "matchIfMetadataSilent")) {
            flag =
                    XMLHelper.getAttributeValueAsBoolean(configElement
                            .getAttributeNodeNS(null, "matchIfMetadataSilent"));
        }
        builder.addPropertyValue("matchIfMetadataSilent", flag);

        boolean onlyIfChecked = false;
        if (configElement.hasAttributeNS(null, "onlyIfChecked")) {
            onlyIfChecked =
                    XMLHelper.getAttributeValueAsBoolean(configElement.getAttributeNodeNS(null, "onlyIfChecked"));
        }
        builder.addPropertyValue("onlyIfChecked", onlyIfChecked);

        builder.addPropertyReference("serviceAccessDataModule", "uApprove.serviceAccessDataModule");

        builder.addPropertyReference("attributeReleaseModule", "uApprove.attributeReleaseModule");
    }

    /** {@inheritDoc} */
    protected Class getBeanClass(final Element arg0) {
        return AttributeInMetadataMatchFunctor.class;
    }

}