/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.ar;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

import jp.gakunin.uApprovejp.saml2.metadata.Description;

import org.opensaml.saml2.metadata.LocalizedString;

/**
 *
 */
public class LocalizedIntendedUseMap implements Serializable {

    /**
     * 
     */
    private static final long serialVersionUID = -4420945306792723030L;

    private final Map<String, InnerLocalizedIntendedUseMap> attrsMap;

    /**
     * Constructor.
     * 
     */
    public LocalizedIntendedUseMap() {
        attrsMap = new HashMap<String, InnerLocalizedIntendedUseMap>();
    }

    /**
     * @param id
     * @param locale
     * @return
     */
    public boolean containsKey(final String id, final Locale locale) {
        if (!attrsMap.containsKey(id)) {
            return false;
        }

        final InnerLocalizedIntendedUseMap innerLocalizedIntendedUseMap = attrsMap.get(id);
        return innerLocalizedIntendedUseMap.containsKey(locale.getLanguage());
    }

    /**
     * @param attribute
     */
    public void put(final AttributeDetail attribute) {
        final String id = attribute.getId();

        if (attrsMap.containsKey(id)) {
            return;
        }

        final InnerLocalizedIntendedUseMap map = new InnerLocalizedIntendedUseMap();

        for (final Description desc : attribute.getIntendedUseList()) {
            map.put(desc.getDescription());
        }
        attrsMap.put(id, map);
    }

    /**
     * @param id
     * @param locale
     * @return
     */
    public LocalizedString getIntendesUse(final String id, final Locale locale) {
        if (!attrsMap.containsKey(id)) {
            return null;
        }

        final InnerLocalizedIntendedUseMap innerLocalizedIntendedUseMap = attrsMap.get(id);
        return innerLocalizedIntendedUseMap.get(locale.getLanguage());
    }

    /**
     *
     */
    private class InnerLocalizedIntendedUseMap {
        private final Map<String, LocalizedString> descMap;

        /**
         * Constructor.
         * 
         */
        public InnerLocalizedIntendedUseMap() {
            super();
            descMap = new HashMap<String, LocalizedString>();
        }

        /**
         * @param language
         * @return
         */
        public boolean containsKey(final String language) {
            return descMap.containsKey(language);
        }

        /**
         * @param description
         */
        public void put(final LocalizedString description) {
            final String language = description.getLanguage();
            if (descMap.containsKey(language)) {
                return;
            }

            descMap.put(language, description);

        }

        /**
         * @param language
         * @return
         */
        public LocalizedString get(final String language) {
            return descMap.get(language);
        }
    }
}
