/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.consent;

import java.util.List;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import jp.gakunin.uApprovejp.sad.ServiceAccessDataModule;

import org.joda.time.DateTime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ch.SWITCH.aai.uApprove.IdPHelper;
import ch.SWITCH.aai.uApprove.ar.Attribute;
import ch.SWITCH.aai.uApprove.ar.AttributeReleaseModule;

/**
 *
 */
public class OneTimeConsentOperation extends ConsentOperation {
    /** Class logger. */
    private static final Logger logger = LoggerFactory.getLogger(OneTimeConsentOperation.class);

    /**
     * Constructor.
     * 
     * @param serviceAccessDataModule
     * @param attributeReleaseModule
     */
    public OneTimeConsentOperation(final ServiceAccessDataModule serviceAccessDataModule,
            final AttributeReleaseModule attributeReleaseModule) {
        super(serviceAccessDataModule, attributeReleaseModule);
    }

    /** {@inheritDoc} */
    public void consent(final ServletContext servletContext, final HttpServletRequest req) {
        final DateTime consentDate = new DateTime();
        final String principalName = IdPHelper.getPrincipalName(servletContext, req);
        final String relyingPartyId = IdPHelper.getRelyingPartyId(servletContext, req);

        final List<Attribute> attributes = getApprovedAttributes(servletContext, req);

        logger.debug("Create one time consent for user {} to {}.", principalName, relyingPartyId);
        serviceAccessDataModule.consentOnetime(principalName, relyingPartyId, consentDate);
        attributeReleaseModule.clearConsent(principalName, relyingPartyId);
        attributeReleaseModule.consentAttributeRelease(principalName, relyingPartyId, attributes, consentDate);
    }

}
