/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.consent;

import java.util.List;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import jp.gakunin.uApprovejp.ar.UApprovejpSAMLHelper;
import jp.gakunin.uApprovejp.lcsp.ServiceNames;
import jp.gakunin.uApprovejp.sad.ServiceAccessDataModule;

import org.joda.time.DateTime;
import org.json.simple.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ch.SWITCH.aai.uApprove.IdPHelper;
import ch.SWITCH.aai.uApprove.ar.Attribute;
import ch.SWITCH.aai.uApprove.ar.AttributeReleaseModule;
import ch.SWITCH.aai.uApprove.ar.SAMLHelper;

/**
 *
 */
public class ThisServiceConsentOperation extends ConsentOperation {
    /** Class logger. */
    private static final Logger logger = LoggerFactory.getLogger(ThisServiceConsentOperation.class);

    private final UApprovejpSAMLHelper samlHelper;

    /**
     * Constructor.
     * 
     * @param serviceAccessDataModule
     * @param attributeReleaseModule
     * @param samlHelper TODO
     */
    public ThisServiceConsentOperation(final ServiceAccessDataModule serviceAccessDataModule,
            final AttributeReleaseModule attributeReleaseModule, final SAMLHelper samlHelper) {
        super(serviceAccessDataModule, attributeReleaseModule);
        this.samlHelper = new UApprovejpSAMLHelper(samlHelper);
    }

    /** {@inheritDoc} */
    public void consent(final ServletContext servletContext, final HttpServletRequest req) {
        final DateTime consentDate = new DateTime();
        final String principalName = IdPHelper.getPrincipalName(servletContext, req);
        final String relyingPartyId = IdPHelper.getRelyingPartyId(servletContext, req);

        final List<Attribute> attributes = getApprovedAttributes(servletContext, req);

        final ServiceNames serviceNames = samlHelper.readServiceNames(relyingPartyId);
        final JSONObject jsonSerialized = serviceNames.serialize();
        final String serialized = jsonSerialized.toString();

        logger.debug("Create consent for user {} to {}.", principalName, relyingPartyId);
        serviceAccessDataModule.consent(principalName, relyingPartyId, serialized, consentDate);
        attributeReleaseModule.consentAttributeRelease(principalName, relyingPartyId, attributes, consentDate);
    }

}
