/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.lcsp;

import java.io.IOException;
import java.util.Locale;
import java.util.Properties;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.gakunin.uApprovejp.sad.ServiceAccessDataModule;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.context.WebApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;

import ch.SWITCH.aai.uApprove.IdPHelper;
import ch.SWITCH.aai.uApprove.ViewHelper;
import ch.SWITCH.aai.uApprove.ar.AttributeReleaseModule;

public class ListApprovalsServlet extends HttpServlet {

    /** Class logger. */
    private final Logger logger = LoggerFactory.getLogger(ListApprovalsServlet.class);

    /** The servlet context. */
    private ServletContext servletContext;

    /** The Service Access Data Module */
    private ServiceAccessDataModule serviceAccessDataModule;

    /** The Attribute Release module. */
    private AttributeReleaseModule attributeReleaseModule;

    private ViewHelper viewHelper;

    private Properties properties;

    /** {@inheritDoc} */
    public void init() throws ServletException {
        try {
            super.init();
            logger.info("init");
            servletContext = getServletContext();
            final WebApplicationContext appContext =
                    WebApplicationContextUtils.getRequiredWebApplicationContext(servletContext);
            serviceAccessDataModule =
                    (ServiceAccessDataModule) appContext.getBean("uApprove.serviceAccessDataModule",
                            ServiceAccessDataModule.class);
            attributeReleaseModule =
                    (AttributeReleaseModule) appContext.getBean("uApprove.attributeReleaseModule",
                            AttributeReleaseModule.class);

            viewHelper = (ViewHelper) appContext.getBean("uApprove.viewHelper", ViewHelper.class);

            properties = (Properties) appContext.getBean("uApprovejp.lcsp", Properties.class);
            if (properties.containsKey("returnURL")) {
                LogoutOperation.setReturnURL(properties.getProperty("returnURL"));
            }

        } catch (final Throwable t) {
            logger.error("Error while initializing Attribute Release Servlet.", t);
            throw new ServletException(t);
        }
    }

    /** {@inheritDoc} */
    @Override
    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException,
            IOException {

        final Locale locale = viewHelper.selectLocale(req);
        req.setAttribute("locale", locale);

        final String principalName = req.getRemoteUser();
        if (principalName == null) {
            logger.warn("principalName is null. Check attribute filter or shbboleth configuration.");
            IdPHelper.handleException(getServletContext(), req, resp, new Throwable("Principal name is null"));
        } else {

            final ShowListApprovalsOperation operation = new ShowListApprovalsOperation();
            operation.execute(req, serviceAccessDataModule, attributeReleaseModule, locale);
            operation.showView(req, resp);
        }
    }

    /** {@inheritDoc} */
    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException,
            IOException {
        final Locale locale = viewHelper.selectLocale(req);
        req.setAttribute("locale", locale);

        try {
            final PageControl pc = PageControl.getPageControl(req);
            final ShowViewOperation operation = pc.getOperation(req, resp);
            // logger.info("PageControl is {}", pc.name());
            // logger.info("Operation is {}", operation.getClass().getName());

            if (operation instanceof ShowListApprovalsOperation) {
                ((ShowListApprovalsOperation) operation).execute(req, serviceAccessDataModule, attributeReleaseModule,
                        locale);
            }
            operation.showView(req, resp);
        } catch (final UnknownControlException e) {
            e.printStackTrace();
            IdPHelper.handleException(getServletContext(), req, resp, e);
        }
    }
}
