/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.lcsp;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.gakunin.uApprovejp.sad.LocalizedServiceAccessData;

/**
 *
 */
public enum PageControl {
    /**
     * 
     */
    LIST_EXIT {
        public ShowViewOperation getOperation(final HttpServletRequest req, final HttpServletResponse resp) {
            // logout SP
            return new LogoutOperation();
        }
    },
    /**
     * Reset general consent.
     */
    RESET_NEXT {
        public ShowViewOperation getOperation(final HttpServletRequest req, final HttpServletResponse resp) {
            return new ShowRevokeApprovalsOperation();
        }
    },
    /**
     * 
     */
    REVOKE_NEXT {
        public ShowViewOperation getOperation(final HttpServletRequest req, final HttpServletResponse resp) {
            final ShowRevokeApprovalsOperation operation = new ShowRevokeApprovalsOperation();
            final String relyingPartyId = req.getParameter("revocation");
            operation.add(relyingPartyId);
            return operation;
        }
    },
    /**
     * 
     */
    REVOKE_ALL_NEXT {
        /** {@inheritDoc} */
        public ShowViewOperation getOperation(final HttpServletRequest req, final HttpServletResponse resp) {

            final ShowRevokeApprovalsOperation operation = new ShowRevokeApprovalsOperation();

            final HttpSession session = req.getSession();
            final List<LocalizedServiceAccessData> serviceAccessDatas =
                    (List<LocalizedServiceAccessData>) session.getAttribute("serviceAccessDatas");
            for (final LocalizedServiceAccessData sad : serviceAccessDatas) {
                operation.add(sad.getRelyingPartyId());
            }

            return operation;
        }
    },
    /**
     * 
     */
    REVOKE_CANCEL {
        public ShowViewOperation getOperation(final HttpServletRequest req, final HttpServletResponse resp) {
            return new ShowListApprovalsOperation();
        }
    },
    /**
     * 
     */
    REVOKE_CONFIRM {
        public ShowViewOperation getOperation(final HttpServletRequest req, final HttpServletResponse resp) {

            final HttpSession session = req.getSession();
            final String[] relyingPartyIds = (String[]) session.getAttribute("revocation_list");

            return new RevokeConfirmOperation(relyingPartyIds);
        }
    },
    ;

    private PageControl() {
    }

    /**
     * @param req
     * @return
     * @throws UnknownControlException
     */
    public static PageControl getPageControl(final HttpServletRequest req) throws UnknownControlException {

        for (final PageControl pc : PageControl.values()) {
            final String control = req.getParameter(pc.name());
            if (control != null) {
                return pc;
            }
        }
        throw new UnknownControlException();
    }

    /**
     * @param req
     * @param resp
     * @return
     */
    public abstract ShowViewOperation getOperation(HttpServletRequest req, final HttpServletResponse resp);
}
