/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.sad;

import java.io.Serializable;
import java.util.Locale;

import jp.gakunin.uApprovejp.lcsp.ServiceNames;

import org.joda.time.DateTime;
import org.json.simple.JSONObject;
import org.json.simple.JSONValue;

/**
 *
 */
public class LocalizedServiceAccessData implements Serializable {

    private static final long serialVersionUID = -8918472687014946314L;

    private final String relyingPartyId;

    private final boolean checkAlways;

    private final String serviceNames;

    /** A timestamp when consent for this attribute release was given. */
    private final DateTime consentDate;

    /** A timestamp when attribute query last time. */
    /** back channel last access. */
    private final DateTime backChannelLastAccess;

    /** back channel access count. */
    private final int backChannelAccessCount;

    /**
     * Constructor.
     * 
     * @param data TODO
     * @param locale TODO
     * 
     */
    public LocalizedServiceAccessData(final ServiceAccessData data, final Locale locale) {
        this.relyingPartyId = data.getRelyingPartyId();
        this.checkAlways = data.isCheckAlways();

        final String serviceNames = data.getServiceNames();
        if (serviceNames != null && !serviceNames.isEmpty()) {
            final JSONObject serialized = (JSONObject) JSONValue.parse(serviceNames);
            final ServiceNames instance = ServiceNames.createInstance(serialized);
            this.serviceNames = instance.getLocalizedServiceName(locale);
        } else {
            this.serviceNames = "";
        }

        this.consentDate = data.getConsentDate();
        this.backChannelLastAccess = data.getBackChannelLastAccess();
        this.backChannelAccessCount = data.getBackChannelAccessCount();
    }

    /** {@inheritDoc} */
    public String getRelyingPartyId() {
        return relyingPartyId;
    }

    /** {@inheritDoc} */
    public boolean isConsented() {
        return (consentDate == null) ? false : true;
    }

    /** {@inheritDoc} */
    public boolean isCheckAlways() {
        return checkAlways;
    }

    /** {@inheritDoc} */
    public boolean isGeneralConsented() {
        return relyingPartyId.equals(ServiceAccessData.WILDCARD);
    }

    /** {@inheritDoc} */
    public String getServiceName() {
        return serviceNames;
    }

    /** {@inheritDoc} */
    public String getConsentDateString() {
        return consentDate.toString("E MMM d HH:mm:ss z y");
    }

    /** {@inheritDoc} */
    public String getBackChannelLastAccessString() {
        if (backChannelLastAccess == null) {
            return "N/A";
        }
        return backChannelLastAccess.toString("E MMM d HH:mm:ss z y");
    }

    /** {@inheritDoc} */
    public String getBackChannelAccessCountString() {
        if (backChannelAccessCount == 0) {
            return "N/A";
        }
        return Integer.toString(backChannelAccessCount);
    }

}
