/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.sad;

import org.joda.time.DateTime;

/**
 *
 */
public class ServiceAccessData {

    /**
     * Wildcard string used for relying party id, attribute id and attribute values hash, when general consent is used.
     */
    public static final String WILDCARD = "*";

    private String relyingPartyId;

    private boolean checkAlways;

    private String serviceNames;

    /** A timestamp when consent for this attribute release was given. */
    private DateTime consentDate;

    /** A timestamp when attribute query last time. */
    /** back channel last access. */
    private DateTime backChannelLastAccess;

    /** back channel access count. */
    private int backChannelAccessCount;

    /**
     * Constructor.
     * 
     */
    public ServiceAccessData() {
        // TODO Auto-generated constructor stub
    }

    /**
     * Constructor.
     * 
     * @param relyingPartyId
     * @param checkAlways
     * @param serviceNames
     * @param consentDate
     */
    public ServiceAccessData(final String relyingPartyId) {
        this(relyingPartyId, false, null, null, null, 0);
    }

    /**
     * Constructor.
     * 
     * @param relyingPartyId
     * @param checkAlways
     * @param serviceNames
     * @param consentDate
     */
    public ServiceAccessData(final String relyingPartyId, final boolean checkAlways, final String serviceNames,
            final DateTime consentDate) {
        this(relyingPartyId, checkAlways, serviceNames, consentDate, null, 0);
    }

    /**
     * Constructor.
     * 
     * @param relyingPartyId
     * @param checkAlways
     * @param serviceNames
     * @param consentDate
     * @param backChannelLastAccess
     * @param backChannelAccessCount
     */
    public ServiceAccessData(final String relyingPartyId, final boolean checkAlways, final String serviceNames,
            final DateTime consentDate, final DateTime backChannelLastAccess, final int backChannelAccessCount) {
        this.relyingPartyId = relyingPartyId;
        this.checkAlways = checkAlways;
        this.serviceNames = serviceNames;
        this.consentDate = consentDate;
        this.backChannelLastAccess = backChannelLastAccess;
        this.backChannelAccessCount = backChannelAccessCount;
    }

    /**
     * @return Returns the relyingPartyId.
     */
    public String getRelyingPartyId() {
        return relyingPartyId;
    }

    /**
     * @return Returns true if the user has consented the service.
     */
    public boolean isConsented() {
        return (consentDate == null) ? false : true;
    }

    /**
     * @return Returns the checkAlways.
     */
    public boolean isCheckAlways() {
        return checkAlways;
    }

    /**
     * @return
     */
    public boolean isGeneralConsented() {
        return relyingPartyId.equals(WILDCARD);
    }

    /**
     * @return Returns the serviceNames.
     */
    public String getServiceNames() {
        return serviceNames;
    }

    /**
     * @return Returns the consentDate.
     */
    public DateTime getConsentDate() {
        return consentDate;
    }

    /**
     * @return Returns the backChannelLastAccess.
     */
    public DateTime getBackChannelLastAccess() {
        return backChannelLastAccess;
    }

    /**
     * @return Returns the backChannelAccessCount.
     */
    public int getBackChannelAccessCount() {
        return backChannelAccessCount;
    }

    /**
     * 
     */
    public void updateBackChannelAccess() {
        backChannelAccessCount++;
        backChannelLastAccess = new DateTime();
    }
}
