/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.sad.storage;

import java.util.Collections;
import java.util.List;

import jp.gakunin.uApprovejp.sad.ServiceAccessData;

import org.joda.time.DateTime;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * No operation implementation of the attribute release consent storage interface. I.e., this implementation will not
 * persist any data nor get any data.
 */
public class NOPStorage implements Storage {

    /** Class logger. */
    private final Logger logger = LoggerFactory.getLogger(NOPStorage.class);

    /** {@inheritDoc} */
    public void initialize() {
    }

    /** {@inheritDoc} */
    public void createServiceAccessData(final String userId, final ServiceAccessData serviceAccessData) {
        logger.info("createServiceAccessData({}, {})", userId, serviceAccessData.getRelyingPartyId());
        return;
    }

    /** {@inheritDoc} */
    public ServiceAccessData readServiceAccessData(final String userId, final String relyingPartyId) {
        logger.info("readServiceAccessData({}, {})", userId, relyingPartyId);
        return null;
    }

    /** {@inheritDoc} */
    public void updateServiceAccessData(final String userId, final String relyingPartyId, final String serviceNames,
            final DateTime consentDate, final boolean onetime) {
        logger.info("updateSADCheckAlways({}, {})", userId, relyingPartyId);
    }

    /** {@inheritDoc} */
    public void deleteServiceAccessData(final String userId, final String relyingPartyId) {
        logger.info("deleteServiceAccessData({}, {})", userId, relyingPartyId);
    }

    /** {@inheritDoc} */
    public void clearServiceAccessData(final String userId) {
        logger.info("clearServiceAccessData({})", userId);

    }

    /** {@inheritDoc} */
    public boolean containsServiceAccessData(final String userId, final String relyingPartyId) {
        logger.info("containsServiceAccessData({}, {})", userId, relyingPartyId);
        return false;
    }

    /** {@inheritDoc} */
    public void updateSADBackChannelAccess(final String userId, final String relyingPartyId,
            final ServiceAccessData serviceAccessData) {
        logger.info("updateSADBackChannelAccess({}, {})", userId, relyingPartyId);
    }

    /** {@inheritDoc} */
    public List<ServiceAccessData> readServiceAccessDatas(final String userId) {
        logger.info("readServiceAccessDatas({}, {})", userId);
        return Collections.emptyList();
    }

}
