/*
 * Copyright (c) 2014, National Institute of Informatics
 */

package jp.gakunin.uApprovejp.sad.storage;

import java.util.List;

import jp.gakunin.uApprovejp.sad.ServiceAccessData;

import org.joda.time.DateTime;

/** Storage interface for user consent. */
public interface Storage {

    public void initialize();

    /**
     * Creates an service access data for a specific user and relying party.
     * 
     * @param userId The user id.
     * @param serviceAccessData The service access data.
     */
    public void createServiceAccessData(final String userId, final ServiceAccessData serviceAccessData);

    /**
     * Reads the service access data from the storage for a specific user and relying party.
     * 
     * @param userId The user id.
     * @param relyingPartyId The relying party id.
     * @return Returns a service access data, might be null.
     */
    public ServiceAccessData readServiceAccessData(final String userId, final String relyingPartyId);

    /**
     * Updates the service access data for a specific user and relying party.
     * 
     * @param userId The user id.
     * @param relyingPartyId The relying party id.
     * @param serviceNames TODO
     * @param consentDate
     * @param onetime
     */
    public void updateServiceAccessData(final String userId, final String relyingPartyId, String serviceNames,
            final DateTime consentDate, final boolean onetime);

    /**
     * Deletes the service access data from the storage for a specific user and relying party.
     * 
     * @param userId The user id.
     * @param relyingPartyId The relying party id.
     */
    public void deleteServiceAccessData(final String userId, final String relyingPartyId);

    /**
     * Deletes the service access data from the storage for a specific user.
     * 
     * @param userId The user id.
     */
    public void clearServiceAccessData(final String userId);

    /**
     * Checks if the storage contains service access data for a specific user, relying party and attribute.
     * 
     * @param userId The user id.
     * @param relyingPartyId The relying party id.
     * @return Returns true if the storage contains service access data, false otherwise.
     */
    public boolean containsServiceAccessData(final String userId, final String relyingPartyId);

    /**
     * Updates the service access data for a specific user and relying party.
     * 
     * @param userId The user id.
     * @param relyingPartyId The relying party id.
     * @param serviceAccessData The service access data.
     */
    public void updateSADBackChannelAccess(final String userId, final String relyingPartyId,
            final ServiceAccessData serviceAccessData);

    /**
     * Reads the service access data from the storage for a specific user.
     * 
     * @param userId The user id.
     * @return Returns a collection of service access datas, might be empty but never null.
     */
    public List<ServiceAccessData> readServiceAccessDatas(final String userId);

}